import './main.css'

// Create the animation
anime({
    targets: ".translate-y-animate", // Target element
    translateY: [-10, 10], // Move up and down
    duration: 1000, // Duration of one cycle
    easing: "easeInOutSine", // Smooth easing
    direction: "alternate", // Go back and forth
    loop: true, // Infinite loop
});

anime({
    targets: ".translate-down-animate", // Target element
    translateY: [-2, 2], // Move up and down
    duration: 500, // Duration of one cycle
    easing: "easeInOutSine", // Smooth easing
    direction: "alternate", // Go back and forth
    loop: true, // Infinite loop
});

anime({
    targets: ".translate-rotate-animate", // Target element
    translateX: [-10, 10], // Move left and right
    translateY: [-10, 10], // Move up and down
    rotate: [-5, 5], // Rotate slightly
    duration: 2000, // Duration of one cycle
    easing: "easeInOutSine", // Smooth easing
    direction: "alternate", // Go back and forth
    loop: true, // Infinite loop
});

const nineItems = document.querySelectorAll(".nine-items");

nineItems.forEach((el, index) => {
    anime({
        targets: el,
        translateX: [
            {
                value: anime.random(-10, 10),
                duration: 1000,
            },
        ],
        translateY: [
            {
                value: anime.random(-10, 10),
                duration: 1000,
            },
        ],
        direction: "alternate",
        easing: "easeInOutSine",
        loop: true,
    });
});

document.querySelectorAll(".works-box").forEach((el, i) => {
    el.addEventListener("mouseenter", () => {
        anime({
            targets: document.querySelectorAll(".works-box-image")[i],
            translateY: -20, // حرکت به بالا
            duration: 500,
            easing: "easeOutQuad",
        });
    });

    el.addEventListener("mouseleave", () => {
        anime({
            targets: document.querySelectorAll(".works-box-image")[i],
            translateY: 0, // برگشت به حالت اولیه
            duration: 500,
            easing: "easeOutQuad",
        });
    });
});

window.onload = () => {
    // پیدا کردن تمام dropdownها
    const dropdowns = document.querySelectorAll('.dropdown-container');

    // اضافه کردن event listener به هر dropdown
    dropdowns.forEach(dropdown => {
        const opener = dropdown.querySelector('.dropdown-opener');
        const content = dropdown.querySelector('.dropdown-content');

        // مخفی کردن اولیه محتوا
        content.style.display = 'none';

        // مدیریت کلیک روی opener
        opener.addEventListener('click', function (e) {
            e.stopPropagation();

            // اگر محتوا در حال نمایش است، آن را مخفی کن
            if (content.style.display === 'block') {
                content.style.display = 'none';
                return;
            }

            // ابتدا تمام dropdownهای دیگر را ببند
            closeAllDropdowns();

            // نمایش محتوای dropdown فعلی
            content.style.display = 'block';
        });

        // جلوگیری از بسته شدن وقتی روی محتوای dropdown کلیک می‌شود
        content.addEventListener('click', function (e) {
            e.stopPropagation();
        });
    });

    // بستن تمام dropdownها با کلیک در هر جای دیگر صفحه
    document.addEventListener('click', closeAllDropdowns);

    // تابع برای بستن تمام dropdownها
    function closeAllDropdowns() {
        document.querySelectorAll('.dropdown-content').forEach(content => {
            content.style.display = 'none';
        });
    }

    const searchOpener = document.querySelector('.search-opener');
    const searchCloser = document.querySelector('.search-closer');
    const searchContent = document.querySelector('.search-content');
    const searchInput = document.querySelector('.search-content input');

    // وقتی روی .search-opener کلیک می‌شود، .search-content نمایش داده شود
    searchOpener.addEventListener('click', function () {
        searchContent.classList.remove('invisible'); // نمایش دادن محتوا
        searchContent.classList.remove('opacity-0');
        searchInput.style.width = "140px";
    });

    // وقتی روی .search-closer کلیک می‌شود، .search-content مخفی شود
    searchCloser.addEventListener('click', function () {
        searchContent.classList.add('invisible'); // مخفی کردن محتوا
        searchContent.classList.add('opacity-0');
        searchInput.style.width = "0px";
    });

    // انتخاب تمام المان‌ها
    let elements = document.querySelectorAll('.circle-anime-container');
    let currentIndex = 0;
    let animationInterval = null;

    // تابع برای اعمال کلاس‌ها
    function updateClasses() {
        elements.forEach((element, index) => {
            element.classList.remove(
                'active',
                'next-right-first',
                'next-right-second',
                'next-left-first',
                'next-left-second'
            );

            if (index === currentIndex) {
                element.classList.add('active');
            } else if (index === (currentIndex + 1) % elements.length) {
                element.classList.add('next-right-first');
            } else if (index === (currentIndex + 2) % elements.length) {
                element.classList.add('next-right-second');
            } else if (index === (currentIndex - 1 + elements.length) % elements.length) {
                element.classList.add('next-left-first');
            } else if (index === (currentIndex - 2 + elements.length) % elements.length) {
                element.classList.add('next-left-second');
            }
        });
    }

    // تابع برای شروع یا ریست انیمیشن خودکار
    function startAutoAnimation() {
        if (animationInterval) clearInterval(animationInterval);

        animationInterval = setInterval(() => {
            currentIndex = (currentIndex + 1) % elements.length;
            updateClasses();
        }, 6000);
    }

    // هندل کلیک روی هر عنصر
    elements.forEach((element, index) => {
        element.addEventListener('click', () => {
            currentIndex = index; // آپدیت ایندکس فعلی
            updateClasses();      // اجرای دستی انیمیشن
            startAutoAnimation(); // ریست تایمر
        });
    });

    // شروع اولیه
    updateClasses();
    startAutoAnimation();

    const modalBackground = document.querySelector(".modal-background");

    document.querySelectorAll('.open-modal').forEach((button, i) => {
        button.addEventListener('click', () => {
            let buttonData = button.getAttribute("data-modal-button");
            let modalContent = document.querySelector("[data-modal='" + buttonData + "']");
            modalBackground.style.display = 'block'; // نمایش مودال
            modalContent.style.display = 'flex'; // نمایش مودال
        });
    });

    document.querySelectorAll('.close-modal').forEach((button, i) => {
        button.addEventListener('click', () => {
            let buttonData = button.getAttribute("data-modal-button");
            let modalContent = document.querySelector("[data-modal='" + buttonData + "']");
            modalBackground.style.display = 'none'; // نمایش مودال
            modalContent.style.display = 'none'; // نمایش مودال
        });
    });

    const qaContainer = document.querySelectorAll(".qa-container");
    const qaContent = document.querySelectorAll(".qa-content");

    document.querySelectorAll('.qa-toggler').forEach((button, i) => {
        button.addEventListener('click', () => {
            let content = qaContent[i]; // گرفتن `.qa-content` مربوطه
            let container = qaContainer[i];

            if (content.style.maxHeight) {
                content.style.maxHeight = null; // بسته شدن
                content.classList.add("opacity-0")
                content.classList.add("invisible")
                container.style.borderRadius = "2rem"; // بسته شدن
            } else {
                content.style.maxHeight = content.scrollHeight + "px"; // باز شدن
                content.classList.remove("opacity-0")
                content.classList.remove("invisible")
                container.style.borderRadius = "1rem"; // بسته شدن
            }
        });
    });

    document.querySelector(".go-to-footer").addEventListener("click", function () {
        let start = window.scrollY;
        let end = document.body.scrollHeight;
        let duration = 800; // مدت زمان اسکرول (به میلی‌ثانیه)
        let startTime = null;

        function animateScroll(currentTime) {
            if (!startTime) startTime = currentTime;
            let timeElapsed = currentTime - startTime;
            let progress = Math.min(timeElapsed / duration, 1);

            window.scrollTo(0, start + (end - start) * progress);

            if (timeElapsed < duration) {
                requestAnimationFrame(animateScroll);
            }
        }

        requestAnimationFrame(animateScroll);
    });

    const allBrands = [
        "../images/brand.png",
        "../images/brand.png",
        "../images/brand.png",
        "../images/brand.png",
        "../images/brand.png",
        "../images/brand.png",
        "../images/brand.png",
        "../images/brand.png",
        "../images/brand.png",
        "../images/whatsapp.png"
    ];

    let CI = 0;
    const visibleCount = 5;
    const slider = document.getElementById('slider');

    function renderInitial() {
        for (let i = 0; i < visibleCount; i++) {
            const div = createSlide(allBrands[i]);
            div.style.left = `${i * 182}px`;
            div.classList.add('opacity-100');
            slider.appendChild(div);
        }
    }

    function createSlide(src) {
        const div = document.createElement('div');
        div.className = "slide-item absolute opacity-0 min-w-[150px] h-[150px] bg-white p-4 rounded-xl shadow-[0_0_20px_0_rgb(0,0,0,.2)] flex items-center justify-center";
        const img = document.createElement('img');
        img.src = src;
        img.alt = '';
        div.appendChild(img);
        return div;
    }

    let isAnimating = false;

    function shiftNext() {
        if (isAnimating || CI + visibleCount >= allBrands.length) return;
        isAnimating = true;

        const first = slider.children[0];
        first.classList.add('animate-slide-out-left');
        setTimeout(() => {
            first.remove();
            isAnimating = false;
        }, 300);

        const newSlide = createSlide(allBrands[CI + visibleCount]);
        newSlide.style.left = `${visibleCount * 182}px`;
        newSlide.classList.add('animate-slide-in-right');
        slider.appendChild(newSlide);

        [...slider.children].forEach((el, i) => {
            el.style.left = `${(i - 1) * 182}px`;
        });

        CI++;
    }

    function shiftPrev() {
        if (isAnimating || CI <= 0) return;
        isAnimating = true;

        const last = slider.children[slider.children.length - 1];
        last.classList.add('animate-slide-out-right');
        setTimeout(() => {
            last.remove();
            isAnimating = false;
        }, 300);

        const newSlide = createSlide(allBrands[CI - 1]);
        newSlide.style.left = `-182px`;
        newSlide.classList.add('animate-slide-in-left');
        slider.prepend(newSlide);

        [...slider.children].forEach((el, i) => {
            el.style.left = `${i * 182}px`;
        });

        CI--;
    }

    document.getElementById('nextBtn').addEventListener('click', shiftNext);
    document.getElementById('prevBtn').addEventListener('click', shiftPrev);

    renderInitial();

    const opener = document.querySelector('.mobile-menu-opener');
    const menu = document.querySelector('.mobile-menu');
    const background = document.querySelector('.mobile-menu-background');
    const mainHeader = document.querySelector(".main-header");

    // باز و بسته شدن با دکمه
    opener.addEventListener('click', () => {
        menu.style.opacity = "1";
        menu.style.visibility = "visible";
        background.style.opacity = "1";
        background.style.visibility = "visible";
        mainHeader.style.zIndex = "6"
        document.querySelector("body").style.overflow = "hidden"
    });

    // بستن با کلیک روی پس‌زمینه
    background.addEventListener('click', () => {
        menu.style.opacity = "0";
        menu.style.visibility = "hidden";
        background.style.opacity = "0";
        background.style.visibility = "hidden";
        mainHeader.style.zIndex = "4"
        document.querySelector("body").style.overflow = "auto"
    });
}